Struct RandomnessRound
pub struct RandomnessRound(/* private fields */);Expand description
Round number of generated randomness.
BCS
The BCS serialized form for this type is defined by the following ABNF:
randomness-round = u64Implementations
impl RandomnessRound
impl RandomnessRound
pub fn new(round: u64) -> RandomnessRound
pub fn value(&self) -> u64
pub fn checked_add(self, rhs: u64) -> Option<RandomnessRound>
pub fn checked_sub(self, rhs: u64) -> Option<RandomnessRound>
pub fn signature_message(&self) -> Vec<u8> ⓘ
pub fn signature_message(&self) -> Vec<u8> ⓘ
Returns the message to be signed for a randomness round.