IotaSignature

Trait IotaSignature 

pub trait IotaSignature: Sized {
    // Required method
    fn verify_secure<T>(
        &self,
        value: &IntentMessage<T>,
        author: Address,
    ) -> IotaResult<()>
       where T: Serialize;

    // Provided methods
    fn new_hashed(
        hashed_msg: &[u8],
        secret: impl Into<IotaKeyPair>,
    ) -> Signature { ... }
    fn new_secure<T>(
        value: &IntentMessage<T>,
        secret: impl Into<IotaKeyPair>,
    ) -> Signature
       where T: Serialize { ... }
}
Node-only behaviour layered on top of the SDK Signature (iota_sdk_types::SimpleSignature): construction from a signer and intent-message verification.

Required Methods

fn verify_secure<T>( &self, value: &IntentMessage<T>, author: Address, ) -> IotaResult<()>
where T: Serialize,

Provided Methods

fn new_hashed(hashed_msg: &[u8], secret: impl Into<IotaKeyPair>) -> Signature

Signs a message that is already in hashed form.

fn new_secure<T>( value: &IntentMessage<T>, secret: impl Into<IotaKeyPair>, ) -> Signature
where T: Serialize,

Signs the BCS hash of the value wrapped in the intent message.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors